function G = makePipeGrid(diameter, length, alpha)
% Makes a pipe shaped grid.
%
% SYNOPSIS:
%   G = makePipeGrid(diameter, length, alpha)
%   G = makePipeGrid()
%
% PARAMETERS:
%   diameter    - Number of grid points in the y- and z-direction.
%   length:     - Number of grid points in the x-direction.
%   alpha:      - Twisting of the grid in radians, alpha = 0 gives no
%                 twisting
% RETURNS:
%   G           - Grid structure as defined by grid_structure
%

%{
Copyright 2012 Ruben Bø.

This file is part of the Curved Mimetic Finite-Difference module (CMFD).
CMFD is a module for the MATLAB Reservoir Simulation Toolbox (MRST).

CMFD is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CMFD is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CMFD.  If not, see <http://www.gnu.org/licenses/>.

%}

    if nargin == 0
        nx = 10; ny = 6; alpha = pi/4;
    else
        nx = length;
        ny = diameter;
    end
    nz = ny; assert(mod(ny,2) == 0)
    
    G = cartGrid([nx,ny,nz]);
    X = G.nodes.coords(:,1);
    Y = G.nodes.coords(:,2);
    Z = G.nodes.coords(:,3);
    Y = Y - ny/2; Z = Z - nz/2;
    
    [TH,R,X] = cart2pol(Y,Z,X);
    layers = cell(1,ny/2);
    for j = 1:ny/2;
        layers{j} = and(or(abs(Y)==j,abs(Z)==j),and(abs(Y) <= j,abs(Z) <= j));
        R(layers{j}) = j;
    end
    
    TH = TH + alpha/nx*X;
    
    [Y,Z,~] = pol2cart(TH,R,X);
       
    G.nodes.coords(:,2) = Y; G.nodes.coords(:,3) = Z;
    G = computeGeometry(G);
    
end