function G = testCMFD

    nx = 8; ny = 6; nz = 6;
    
    strX = 1; strY = 1;
    alpha = 2*pi/3; beta = 3*pi/5;
    [X, Y] = ndgrid(linspace(0, alpha, nx+1), linspace(0, beta, ny+1));
    Z = 0.5*sin(X).*sin(Y);

    grdecl = cartesianGrdecl(0:strX:strX*nx, 0:strY:strY*ny, 0:nz, 'depthz', Z);

    G = processGRDECL(grdecl);  
    G = computeGeometry(G);

    rock.perm = repmat(50*milli*darcy, [G.cells.num, 1]);
    rock.perm(1:nx*ny) = repmat(1*milli*darcy, [nx*ny, 1]);
    rock.perm(nx*ny*(nz-1)+1:nx*ny*nz) = repmat(1*milli*darcy, [nx*ny, 1]);
    
    grdecl.PERMX = rock.perm;
    
    fluid = initSingleFluid('mu', 1*centi*poise, 'rho', 1014*kilogram/meter^3);

    bc = pside([], G, 'XMin', 1*barsa());
    bc = pside(bc, G, 'XMax', 0*barsa());
    
    
    % The mimetic method
    Smim = computeMimeticIP(G,rock);
    stateMim = initResSol(G,0);
    stateMim = solveIncompFlow(stateMim,G,Smim,fluid,'bc',bc);
    
    % The curved mimetic method with an incorrect continuity condition
    stateCur = initResSol(G,0); 
    G = computeCmatrix(G,0);
    Scur = computeCurMimeticIP(G,rock);
    stateCur = solveIncompFlowCMFD(stateCur, G, Scur, fluid, 'bc', bc);
    
    % The new curved mimetic method (correct when makeKalpha.m is run)
    G = computeCmatrix(G,0);
    SnCur = computeCurMimeticIP(G, rock, 'InnerProduct', 'ip_simple');    
    stateNewCur = initResSol(G,0); 
    G = makeKalpha(G,rock);
    stateNewCur = solveIncompFlowCMFD(stateNewCur, G, SnCur, fluid, 'bc', bc);

%     plotGrid(G, 'facea', 0.3, 'edgea', 0.1), view(-10,15)
%     hold on, plotCellData(G,convertTo(stateCur.pressure,barsa)), colorbar
    
    figure, subplot(1,2,1), plot(stateMim.flux)
    hold on, plot(stateCur.flux,'r'), title('Mimetic (blue) and curved mimetic (red)')
    
    subplot(1,2,2), plot(stateMim.flux)
    hold on, plot(stateNewCur.flux,'r'), title('Mimetic (blue) and new curved mimetic (red)')
            
end