function testNewBC

    nx = 10; 
    G = makePipeGrid(6,nx,pi/4);
    
    k = 1;
    rock.perm = repmat(k*milli*darcy, [G.cells.num, 1]);    
    fluid = initSingleFluid('mu', 1*centi*poise, 'rho', 1014*kilogram/meter^3);

    bc = pside([], G, 'XMin', 0*barsa());
    bc = pside(bc, G, 'XMax', 1*barsa());
    
    % run mimetic on org grid
    S = computeMimeticIP(G,rock);
    stateorg = initResSol(G,0);
    stateorg = solveIncompFlow(stateorg,G,S,fluid,'bc',bc);
    
    % run curved 
    G3 = computeCmatrix(G,0);
    rSolorg2 = initResSol(G3,0); 
    S3 = computeCurMimeticIP(G3,rock);
    rSolorg2 = solveIncompFlowCMFDnew(rSolorg2, G3, S3, fluid, 'bc', bc);
    
    
    % run curved with new BC
    G2 = computeCmatrix(G,0,0,1); % the last two options gives curvedBC
    S2 = computeCurMimeticIP(G2, rock, 'InnerProduct', 'ip_simple');    
    rSolorg = initResSol(G2,0); 
    G2 = makeKalpha(G2,rock);
    rSolorg = solveIncompFlowCMFDnew(rSolorg, G2, S2, fluid, 'bc', bc);
       
    pex = computeExact(G,nx);
    fex = computeExactFlux(G,0,1,nx,k,fluid);
    
    f = stateorg.flux; p = convertTo(stateorg.pressure,barsa);
    fc = rSolorg2.flux; pc = convertTo(rSolorg2.pressure,barsa);
    fcBC = rSolorg.flux; pcBC = convertTo(rSolorg.pressure,barsa);
    
    figure, 
    subplot(1,3,1), plot((f-fex)/norm(fex,inf))
    subplot(1,3,2), plot((fc-fex)/norm(fex,inf))
    subplot(1,3,3), plot((fcBC-fex)/norm(fex,inf))
    
    
    fprintf('\n Relative error in L2 norm for the flux');
    fprintf(['\n Mimetic:       ', num2str(norm(f-fex)/norm(fex))])
    fprintf(['\n Curved:        ', num2str(norm(fc-fex)/norm(fex))])
    fprintf(['\n Curved new BC: ', num2str(norm(fcBC-fex)/norm(fex)),'\n'])

    fprintf('\n Relative error in L2 norm for the pressure');
    fprintf(['\n Mimetic:       ', num2str(norm(p-pex)/norm(pex))])
    fprintf(['\n Curved:        ', num2str(norm(pc-pex)/norm(pex))])
    fprintf(['\n Curved new BC: ', num2str(norm(pcBC-pex)/norm(pex)),'\n'])
    
    figure, plotGrid(G, 'facea', 0.3, 'edgea', 0.1), view(3)
    hold on
    nn = 1:G.faces.num;
%     ff = G.faces.curvature > 0;
    ff = abs(f-fex)/norm(fex,inf) > 5e-4;
    f = nn(ff);
    plotFaces(G,f)
    
    figure, plotGrid(G, 'facea', 0.3, 'edgea', 0.1), view(3)
    hold on
    nn = 1:G.faces.num;
    ff = abs(fcBC-fex)/norm(fex,inf) > 5e-3;
    f = nn(ff);
    plotFaces(G,f)
    
end 
    
function f = computeExactFlux(G, p_left, p_right, Lx, k, fluid)

    f = (p_left - p_right)*barsa()*k*milli*darcy/fluid.properties()/Lx;
    f = f*G.faces.normals(:,1);
    
end

function p = computeExact(G,Lx)
%computing the exact pressure
    
        p = G.cells.centroids(:,1)/Lx;

end
    